@@ -21,6 +21,8 @@ python-deltasigma
 :Release: |release|
 :Date: |today|
 
+Homepage: https:///github.com/ggventurini/python-deltasigma
+
 Introduction
 ------------
 
@@ -36,6 +38,9 @@ Toolbox <http://www.mathworks.com/matlabcentral/fileexchange/19-delta-sigma-tool
 the *de facto* standard tool for high-level delta sigma simulation, upon
 which it is very heavily based.\ |githalytics.com alpha|
 
+Status
+------
+
 This project is a *work in progress*, not all functionality has been
 ported, yet. The next figure shows the relationship between the main functions
 and the avaliable functionality at a glance.
@@ -45,23 +50,23 @@ and the avaliable functionality at a glance.
 To see the currently implemented functionality in action, take a look
 at the following ipython notebooks:
 
--  `dsdemo1 <http://nbviewer.ipython.org/gist/ggventurini/8040189>`__,
+-  `dsdemo1 <http://nbviewer.ipython.org/urls/raw.githubusercontent.com/ggventurini/python-deltasigma/master/examples/dsdemo1.ipynb>`__,
    notebook port of the interactive ``dsdemo1.m``.
--  `dsdemo2 <http://nbviewer.ipython.org/gist/ggventurini/8044644>`__,
+-  `dsdemo2 <http://nbviewer.ipython.org/urls/raw.githubusercontent.com/ggventurini/python-deltasigma/master/examples/dsdemo2.ipynb>`__,
    notebook port of the interactive ``dsdemo2.m``.
--  `dsdemo3 <http://nbviewer.ipython.org/gist/ggventurini/10016971>`__,
-   notebook port of the interactive ``dsdemo3.m``.
--  `dsdemo4 <http://nbviewer.ipython.org/gist/ggventurini/8255785/dsdemo4.ipynb>`__,
+-  `dsdemo3 <http://nbviewer.ipython.org/urls/raw.githubusercontent.com/ggventurini/python-deltasigma/master/examples/dsdemo3.ipynb>`__,
+   notebook port of the interactive `dsdemo3.m`.
+-  `dsdemo4 <http://nbviewer.ipython.org/urls/raw.githubusercontent.com/ggventurini/python-deltasigma/master/examples/dsdemo4.ipynb>`__,
    notebook port of ``dsdemo4.m``. `Audio
-   file <https://gist.github.com/ggventurini/8255785/raw/8fb7d94236b917e6d557fb538d3f35a3144c038c/sax.wav.b64>`__.
--  `dsexample1 <http://nbviewer.ipython.org/7251113>`__, python
+   file <https://raw.githubusercontent.com/ggventurini/python-deltasigma/master/examples/sax.wav.b64>`__, right click to download.
+-  `dsexample1 <http://nbviewer.ipython.org/urls/raw.githubusercontent.com/ggventurini/python-deltasigma/master/examples/dsexample1.ipynb>`__, python
    version of ``dsexample1.m``.
--  `dsexample2 <http://nbviewer.ipython.org/8323435>`__, python
+-  `dsexample2 <http://nbviewer.ipython.org/urls/raw.githubusercontent.com/ggventurini/python-deltasigma/master/examples/dsexample2.ipynb>`__, python
    version of ``dsexample2.m``.
--  `dsexample3 <http://nbviewer.ipython.org/8323046>`__, python
+-  `dsexample3 <http://nbviewer.ipython.org/urls/raw.githubusercontent.com/ggventurini/python-deltasigma/master/examples/dsexample3.ipynb>`__, python
    version of ``dsexample3.m``.
 
-They are also good for getting started quickly.
+They are also a good means for getting started quickly.
 
 If you have some examples you would like to share, `send me a
 mail <http://tinymailto.com/5310>`__, and I will add them to the above
@@ -599,7 +604,7 @@ __author__ = "Giuseppe Venturini and the python-deltasigma contributors"
 __copyright__ = "Copyright 2013, Giuseppe Venturini"
 __credits__ = ["Giuseppe Venturini"]
 __license__ = "BSD 2-Clause License"
-__version__ = '0.1-2'
+__version__ = '0.1-3'
 __maintainer__ = "Giuseppe Venturini"
 __email__ = "ggventurini+github@gmail.com"
 __status__ = "Stable"
