@@ -18,7 +18,6 @@
  that do not find a direct replacement in numpy/scipy.
 """
 
-from warnings import warn
 import collections
 import fractions
 from fractions import Fraction as Fr
@@ -155,7 +154,7 @@ def minreal(tf, tol=None):
     if (hasattr(tf, 'inputs') and not tf.inputs == 1) or \
        (hasattr(tf, 'outputs') and not tf.outputs == 1):
         raise TypeError("Only SISO transfer functions can be evaluated.")
-    if (hasattr(tf, 'zeros') and hasattr(tf, 'poles')):
+    if hasattr(tf, 'zeros') and hasattr(tf, 'poles'):
         # LTI objects have poles and zeros,
         zeros = tf.zeros
         poles = tf.poles
@@ -360,9 +359,11 @@ def pretty_lti(arg):
         if ppstr[0] == '1' and len(ppstr[1]) and float(ppstr[1]) != 1.:
             ppstr[0] = ppstr[1][:-1]
             ppstr[1] = ""
-        ppstr[1] += "-" * (max(len(ppstr[0]), len(ppstr[2])) + 2)
-        ppstr[0] = ppstr[0].center(len(ppstr[1]))
-        ppstr[2] = ppstr[2].center(len(ppstr[1]))
+        space_pad_ln = len(ppstr[1])
+        fraction_line = "-" * (max(len(ppstr[0]), len(ppstr[2])) + 2)
+        ppstr[1] += fraction_line
+        ppstr[0] = " "*space_pad_ln + ppstr[0].center(len(fraction_line))
+        ppstr[2] = " "*space_pad_ln + ppstr[2].center(len(fraction_line))
     return "\n".join(ppstr)
 
 
@@ -401,7 +402,7 @@ def _get_zpk(arg, input=0):
     elif hasattr(arg, '__class__') and arg.__class__.__name__ == 'lti':
         z, p, k = arg.zeros, arg.poles, arg.gain
     elif _is_zpk(arg):
-        z, p, k = carray(arg[0]).squeeze(), carray(arg[1]).squeeze(), arg[2]
+        z, p, k = np.atleast_1d(arg[0]), np.atleast_1d(arg[1]), arg[2]
     elif _is_num_den(arg):
         sys = lti(*arg)
         z, p, k = sys.zeros, sys.poles, sys.gain
@@ -637,7 +638,7 @@ def _cell_like_list(shape, init=None):
 
     """
     a = []
-    for i in range(shape[0]):
+    for _ in range(shape[0]):
         if len(shape) == 1:
             a.append(init)
         else:
@@ -848,7 +849,7 @@ def test_get_zpk():
 
 def test_get_num_den():
     """Test function for _get_num_den()"""
-    from scipy.signal import zpk2ss, zpk2tf
+    from scipy.signal import zpk2ss
     z = (.4,)
     p = (.9, .1 + .2j, .1 - .2j)
     k = .4
@@ -929,9 +930,9 @@ def test_pretty_lti():
     assert pretty_lti([[], [.22222222], 2]) == \
         '      2       \n--------------\n (z - 0.2222) '
     assert pretty_lti(((0, 0, 1), (1, 2-1j, 2+1j, 2-1j, 2+1j), 5)) == \
-        '        z^2 (z - 1)         \n' + \
+        '         z^2 (z - 1)        \n' + \
         '5 --------------------------\n' + \
-        '  (z^2 - 4z + 5)^2 (z - 1)  '
+        '   (z^2 - 4z + 5)^2 (z - 1) '
 
 
 def test_cell_like_list():
